Page
Library
Module
Module type
Parameter
Class
Class type
Microx_concretizer.mainexpression interpreter that never halts due to an unknown value.
It can be used as mixin class for other interpreters.
constraint 'a = Bap.Std.Expi.contextinherit ['a, Bap.Std.Bil.result] Bap.Std.Expi.Eval.semanticsInteraction with environment
method empty : Bap.Std.Bil.storagecreates an empty storage. If you want to provide your own implementation of storage, then it is definitely the right place.
method lookup : Bap.Std.var -> 'a Bap.Std.Expi.ra variable is looked up in a context
method update : Bap.Std.var -> Bap.Std.Bil.result -> 'a Bap.Std.Expi.ua variable is bind to a value.
method load : Bap.Std.Bil.storage -> Bap.Std.addr -> 'a Bap.Std.Expi.ra byte is loaded from a given address
method store : Bap.Std.Bil.storage ->
Bap.Std.addr ->
Bap.Std.word ->
'a Bap.Std.Expi.ra byte is stored to a a given address
method type_error : Bap.Std.type_error -> 'a Bap.Std.Expi.ra given typing error has occurred
method division_by_zero : unit -> 'a Bap.Std.Expi.rwe can't do this!
method undefined_addr : Bap.Std.addr -> 'a Bap.Std.Expi.rcalled when storage doesn't contain the addr
method undefined_var : Bap.Std.var -> 'a Bap.Std.Expi.rcalled when context doesn't know the variable